package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.TmstruckReceiptResult;
import com.steerinfo.dil.service.ITmstruckReceiptResultService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import com.steerinfo.route.mapper.TmstruckArrivalResultMapper;
import com.steerinfo.route.model.TmstruckReceiptResultChild;
import com.steerinfo.route.service.impl.TmstruckReceiptResultChildServiceImpl;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * TmstruckReceiptResult RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-10 10:10
 * 类描述
 * 修订历史：
 * 日期：2021-09-10
 * 作者：generator
 * 参考：
 * 描述：TmstruckReceiptResult RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/tmstruckreceiptresults")
public class TmstruckReceiptResultController extends BaseRESTfulController {

    @Autowired
    ITmstruckReceiptResultService tmstruckReceiptResultService;
    @Autowired
    TmstruckArrivalResultMapper tmstruckArrivalResultMapper;
    @Autowired
    TmstruckReceiptResultChildServiceImpl tmstruckReceiptResultChildService;

    @Autowired
    ESFeign esFeign;

    @Autowired
    ColumnDataUtil columnDataUtil;

    @ApiOperation(value="查询收货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(107)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getReceiveResult")
    public RESTfulResult getReceiveResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer orderType,
                                          String con
    ){
        mapValue.put("orderTypee", orderType);
        PageHelper.startPage(pageNum,pageSize);
        //分页数据
        List<Map<String, Object>> receiveResult = tmstruckReceiptResultService.getReceiveResult(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,receiveResult);
        return success(pageList);
    }


    @ApiOperation(value="新增钢材到异地库达州站驻港人员确定收货")
    @PostMapping("/addSteelNzReceiptResult")
    public RESTfulResult addSteelNzReceiptResult(@RequestBody(required = false) Map<String, Object> map) {
        int i = tmstruckReceiptResultService.addSteelNzReceiptResult(map);
        return success(i);
    }

    /**
     * 新增收货实绩
     * @param map
     * @return
     */
    @ApiOperation(value="新增收货实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "收货实绩map", required = false, dataType = "java.util.Map")
    })
    @PostMapping(value = "/addTmstruckReceiptResult")
    public RESTfulResult addTmstruckReceiptResult(@RequestBody(required = false) Map<String, Object> map){
        BigDecimal alreadyExistsArrivalResult = tmstruckArrivalResultMapper.alreadyExistsArrivalResult((String) map.get("orderNumber"));
        if(alreadyExistsArrivalResult!=null){
            TmstruckReceiptResult tmstruckReceiptResult = new TmstruckReceiptResult();
            //获取运输订单号和收货点地址
            String orderNumber = (String) map.get("orderNumber");
            String resultArrivalAddress = (String) map.get("resultArrivalAddress");
            //获取空货箱照片、已签字的送货单照片
            String resultEmptyContainerPhoto = (String) map.get("url1");
            String resultSignedNotePhoto = (String) map.get("url2");
            tmstruckReceiptResult.setResultArrivalAddress(resultArrivalAddress);
            tmstruckReceiptResult.setResultEmptyContainerPhoto(resultEmptyContainerPhoto);
            tmstruckReceiptResult.setResultSignedNotePhoto(resultSignedNotePhoto);
            if(map.containsKey("url3")){
                //如果有，获取客户签收单照片
                String resultReceiveNotePhoto = (String) map.get("url3");
                tmstruckReceiptResult.setResultReceiveNotePhoto(resultReceiveNotePhoto);
            }
            //新增收货实绩主表
            BigDecimal receiptResultId = tmstruckReceiptResultService.addTmstruckReceiptResult(orderNumber, tmstruckReceiptResult);
            //初始化收货实绩子表信息
            TmstruckReceiptResultChild tmstruckReceiptResultChild = new TmstruckReceiptResultChild();
            //关联收货实绩主表
            tmstruckReceiptResultChild.setReceiptResultId(receiptResultId);
            //如果有，获取最多三张其他照片
            if(map.containsKey("fourFiles")){
                List<String> fourFiles = (List<String>) map.get("fourFiles");
                if(fourFiles.size()==0){}
                else if(fourFiles.size()==1){
                    tmstruckReceiptResultChild.setOtherPhoto1(fourFiles.get(0));
                }else if(fourFiles.size()==2){
                    tmstruckReceiptResultChild.setOtherPhoto1(fourFiles.get(0));
                    tmstruckReceiptResultChild.setOtherPhoto2(fourFiles.get(1));
                }else {
                    tmstruckReceiptResultChild.setOtherPhoto1(fourFiles.get(0));
                    tmstruckReceiptResultChild.setOtherPhoto2(fourFiles.get(1));
                    tmstruckReceiptResultChild.setOtherPhoto3(fourFiles.get(2));
                }
            }
            //新增收货实绩子表
            int i = tmstruckReceiptResultChildService.addTmstruckReceiptResultChild(tmstruckReceiptResultChild);
            return success(i);
        }else{
            return success(4);
        }

    }



    @ApiOperation(value="展示收货实绩信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(137)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/getReceiptResult")
    public RESTfulResult getReceiptResult(@RequestBody(required=false) Map<String, Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize){

        if(mapValue.containsKey("startTime")&&mapValue.containsKey("endTime")){
            Date startDate=new Date(Long.parseLong(mapValue.get("startTime").toString())) ;
            Date endDate=new Date(Long.parseLong(mapValue.get("endTime").toString())) ;
            Calendar ca = Calendar.getInstance();
            ca.setTime(endDate);
            ca.add(Calendar.DATE,1);
            SimpleDateFormat simpleDateFormat=new SimpleDateFormat("yyyy-MM-dd");
            String startTime1=simpleDateFormat.format(startDate);
            String endTime1=simpleDateFormat.format(ca.getTime());
            mapValue.replace("startTime",startTime1);
            mapValue.replace("endTime",endTime1);
        }
        List<Map<String, Object>> receiptResultInfo = tmstruckReceiptResultService.getReceiptResultInfo(mapValue);
        PageHelper.startPage(pageNum,pageSize);
        List<Map<String, Object>> receiptResultInfo1 = tmstruckReceiptResultService.getReceiptResultInfo(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId,receiptResultInfo,receiptResultInfo1);
        return success(pageList);
    }
}
